@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.039_004';
+our $VERSION = '1.047_001';
 
 =head1 NAME
 
@@ -52,7 +52,7 @@ use constant OPTIONS => {
     'f|filter:s@'    => 'Input filters for scripts',
     'g|gui'          => 'No console window',
     'I|lib:s@'       => 'Include directories (for perl)',
-    'l|link:s@'      => 'Include additional shared libraries',
+    'l|link:s@'      => 'Additional shared libraries to pack',
     'L|log:s'        => 'Where to log packaging process information',
     'F|modfilter:s@' => 'Input filter for perl modules',
     'M|module|add:s@'=> 'Include modules',
@@ -296,13 +296,13 @@ sub _parse_opts {
     $self->{logfh} = $self->_open('>>', $opt->{L})
       if length $opt->{L};
 
-    if ($opt->{E}) {
+    if (defined $opt->{E}) {
         $opt->{e} = "use $];\n#line 1\n$opt->{E}";
         # XXX This is how we should also include additional default modules in the future instead of in require_modules in par.pl!
         push @{ $opt->{M} ||= [] }, 'feature' if $] >= 5.009;
     }
 
-    if ($opt->{e}) {
+    if (defined $opt->{e}) {
         $self->_warn("Using -e 'code' as input file, ignoring @$args\n")
           if (@$args and !$opt->{r});
 
@@ -451,7 +451,6 @@ sub run_pack {
 sub _compile_par {
     my ($self) = @_;
 
-    my @SharedLibs;
     local (@INC) = @INC;
 
     my $lose = $self->{pack_attrib}{lose};
@@ -612,7 +611,7 @@ sub get_par_file {
     if ($opt->{S} or $opt->{p}) {
         # We need to keep it.
 
-        if ($opt->{e} or !@$input) {
+        if (defined $opt->{e} or !@$input) {
             $par_file = (defined $output ? $output : "a.par");
         }
         else {
@@ -888,10 +887,14 @@ sub pack_manifest_hash {
             }
         }
         elsif ($^O eq 'darwin') {
-            # try "otool -D $file", expect output like "$file:\nname\n"
+            # try "otool -D $file", expect itwo lines of output like 
+            #   $file:
+            #   path
+            # Note: some versions of otool report just a name in the
+            # second line, others report a pathname
             chomp(my @ot = qx( otool -D $in ));
             if ($? == 0) {
-                $name = $ot[1];
+                $name = basename($ot[1]);
                 $self->_vprint(1, "... otool: library $in has install name $name");
             }
             else {
@@ -1546,7 +1549,7 @@ sub _find_shlib {
         return $abs_file;
     }
 
-    $self->_die("Shared library (option -l) doesn't exist: $file")
+    $self->_die("Shared library (option --link) doesn't exist: $file")
         if $file =~ /[\/\\]/;
 
     my @libpath;
@@ -1570,7 +1573,7 @@ sub _find_shlib {
         return $lib;
     }
 
-    $self->_die("Can't find shared library (option -l): $file")
+    $self->_die("Can't find shared library (option --link): $file")
         if $^O eq 'MSWin32' || $file =~ /^lib/;
 
     # be extra magical and prepend "lib" to the filename
@@ -1579,7 +1582,7 @@ sub _find_shlib {
         return $lib;
     }
 
-    $self->_die("Can't find shared library (option -l): $file (also tried lib$file)");
+    $self->_die("Can't find shared library (option --link): $file (also tried lib$file)");
 }
 
 sub _find_shlib_in_path
