@@ -210,16 +210,6 @@ BEGIN {
 
 _par_init_env();
 
-if (exists $ENV{PAR_ARGV_0} and $ENV{PAR_ARGV_0} ) {
-    @ARGV = map $ENV{"PAR_ARGV_$_"}, (1 .. $ENV{PAR_ARGC} - 1);
-    $0 = $ENV{PAR_ARGV_0};
-}
-else {
-    for (keys %ENV) {
-        delete $ENV{$_} if /^PAR_ARGV_/;
-    }
-}
-
 my $quiet = !$ENV{PAR_DEBUG};
 
 # fix $progname if invoked from PATH
@@ -309,26 +299,19 @@ my ($start_pos, $data_pos);
 
         return if ref $module or !$module;
 
-        my $filename = delete $require_list{$module} || do {
-            my $key;
-            foreach (keys %require_list) {
-                next unless /\Q$module\E$/;
-                $key = $_; last;
-            }
-            delete $require_list{$key} if defined($key);
-        } or return;
+        my $info = delete $require_list{$module} or return;
 
-        $INC{$module} = "/loader/$filename/$module";
+        $INC{$module} = "/loader/$info/$module";
 
         if ($ENV{PAR_CLEAN} and defined(&IO::File::new)) {
             my $fh = IO::File->new_tmpfile or die $!;
             binmode($fh);
-            print $fh $filename->{buf};
+            print $fh $info->{buf};
             seek($fh, 0, 0);
             return $fh;
         }
         else {
-            my $filename = _tempfile("$filename->{crc}.pm", $filename->{buf});
+            my $filename = _tempfile("$info->{crc}.pm", $info->{buf});
 
             open my $fh, '<', $filename or die "can't read $filename: $!";
             binmode($fh);
@@ -742,6 +725,7 @@ sub require_modules {
     require IO::File;
     require Compress::Zlib;
     require Archive::Zip;
+    require Digest::SHA;
     require PAR;
     require PAR::Heavy;
     require PAR::Dist;
@@ -916,7 +900,7 @@ sub _par_init_env {
         $ENV{PAR_INITIALIZED} = 2;
     }
 
-    for (qw( SPAWNED TEMP CLEAN DEBUG CACHE PROGNAME ARGC ARGV_0 ) ) {
+    for (qw( SPAWNED TEMP CLEAN DEBUG CACHE PROGNAME ) ) {
         delete $ENV{'PAR_'.$_};
     }
     for (qw/ TMPDIR TEMP CLEAN DEBUG /) {
